@@ -83,7 +83,7 @@ static GObjectClass *parent_class;
 #define HANDLE_LIST(py_ret, type, type_name)                           \
     {                                                                  \
         Py_ssize_t i = 0;                                              \
-    	if (!PySequence_Check(py_ret) || PyString_Check(py_ret))       \
+    	if (!PySequence_Check(py_ret) || PyUnicode_Check(py_ret))       \
     	{                                                              \
     		PyErr_SetString(PyExc_TypeError,                           \
     						METHOD_NAME " must return a sequence");    \
@@ -159,14 +159,14 @@ nemo_python_object_get_name_and_desc (NemoNameAndDescProvider *provider)
         {
             PyObject *py_item;
             py_item = PySequence_GetItem (py_ret, i);
-            if (!PyString_Check(py_item))
+            if (!PyUnicode_Check(py_item))
             {
                 PyErr_SetString(PyExc_TypeError,
                                 METHOD_NAME
                                 " must return a sequence of strings");
                 goto beach;
             }
-            ret = g_list_append (ret, (gchar *) PyString_AsString(py_item));
+            ret = g_list_append (ret, (gchar *) PyUnicode_AsUTF8(py_item));
             Py_DECREF(py_item);
         }
  beach:
@@ -237,7 +237,7 @@ nemo_python_object_get_widget (NemoLocationWidgetProvider *provider,
 	CHECK_OBJECT(object);
 	CHECK_METHOD_NAME(object->instance);
 
-	py_uri = PyString_FromString(uri);
+	py_uri = PyUnicode_FromString(uri);
 
 	py_ret = PyObject_CallMethod(object->instance, METHOD_PREFIX METHOD_NAME,
 								 "(NN)", py_uri,
@@ -487,14 +487,14 @@ nemo_python_object_update_file_info (NemoInfoProvider 		*provider,
 	
 	HANDLE_RETVAL(py_ret);
 
-	if (!PyInt_Check(py_ret))
+	if (!PyLong_Check(py_ret))
 	{
 		PyErr_SetString(PyExc_TypeError,
 						METHOD_NAME " must return None or a int");
 		goto beach;
 	}
 
-	ret = PyInt_AsLong(py_ret);
+	ret = PyLong_AsLong(py_ret);
 	
  beach:
  	free_pygobject_data(file, NULL);
@@ -590,7 +590,7 @@ nemo_python_object_get_type (GTypeModule *module,
         NULL
     };
 
-	debug_enter_args("type=%s", PyString_AsString(PyObject_GetAttrString(type, "__name__")));
+	debug_enter_args("type=%s", PyUnicode_AsUTF8(PyObject_GetAttrString(type, "__name__")));
 	info = g_new0 (GTypeInfo, 1);
 	
 	info->class_size = sizeof (NemoPythonObjectClass);
@@ -602,7 +602,7 @@ nemo_python_object_get_type (GTypeModule *module,
 	Py_INCREF(type);
 
 	type_name = g_strdup_printf("%s+NemoPython",
-								PyString_AsString(PyObject_GetAttrString(type, "__name__")));
+								PyUnicode_AsUTF8(PyObject_GetAttrString(type, "__name__")));
 		
 	gtype = g_type_module_register_type (module, 
 										 G_TYPE_OBJECT,
